/// Convert from ADC value to decidegrees.
fn convert(adc: u16) -> u16 {
    // The thermistor is connected via a resistor divider:
    // 
    // VCC <---/\/\/\---+---/\/\/\----> GND
    //           4.7k   |    NTC
    //                  V ADC
    //
    // If we express V_SUP in arbitrary ADC units (0-1023), then we can
    // calculate the resistance as a function of ADC value:
    //
    // R = 4700 / ((1024 / ADC) - 1)

    // Clamp to safe value. This prevents division by zero.
    let adc = if adc >= 1024 { 1024 } else { adc};
    let adc = if adc < 1 { 1 } else { adc };
    let r = 4700 / ((1024 / adc) - 1);
